### Binary normalisation data
For availability of LZc normalisation, download the file [fLZc_data.zip](https://users.sussex.ac.uk/~lionelb/downloads/fLZc_data.zip), and unzip into the `<fLZc_root>/matlab/data` directory.
